@@ -64,6 +64,13 @@ WebEngineHandler::WebEngineHandler(QObject *parent)
     connect(m_voiceToTextHandler, &VoiceToTextHandler::audioLengthLimit, this, [this]() {
         Q_EMIT requestMessageDialog(VNoteMessageDialogHandler::AsrTimeLimit);
     });
+    connect(m_voicePlayerHandler, &VoicePlayerHandler::playStatusChanged, this, [=](VoicePlayerHandler::PlayState state){
+        if (state == VoicePlayerHandler::PlayState::End) {
+            Q_EMIT playingVoice(false);
+        } else {
+            Q_EMIT playingVoice(true);
+        }
+    });
 }
 
 QObject *WebEngineHandler::target() const
